@@ -114,7 +114,7 @@ class Measurement:
             self.spectrometer_id = raw_meas.spectrometer_id
             self.anc_data = raw_meas.anc_data
 
-        self.XYZ = sd_to_XYZ(self.spd, k=6.83)  # TODO colour-science > 0.4.2 k=683
+        self.XYZ = sd_to_XYZ(self.spd, k=683)
         self.xy = XYZ_to_xy(self.XYZ)
         _cct = uv_to_CCT(xy_to_UCS_uv(self.xy))
         self.cct = _cct[0]
@@ -141,6 +141,7 @@ class Measurement:
             Spectral Measurement - {self.spectrometer_id}:
                 time: {self.time}
                 XYZ: {np.array2string(self.XYZ, formatter={'float_kind':lambda x: "%.2f" % x})}
+                xy: {np.array2string(self.xy, formatter={'float_kind':lambda x: "%.4f" % x})}
                 CCT: {self.cct:.0f} ± {self.duv:.5f}
                 Dominant WL: {self.dominant_wl:.1f}
                 Exposure: {self.exposure:.3f}
